@@ -51,7 +51,7 @@ typedef struct SimpleFile_t {
     int size_limited;
 #endif
     int scsi_sector_size;
-    void *extra_data; /* extra system dependant information for scsi */
+    void *extra_data; /* extra system dependent information for scsi */
     int swap; /* do the word swapping */
 } SimpleFile_t;
 
@@ -275,13 +275,15 @@ static int file_data(Stream_t *Stream, time_t *date, mt_size_t *size,
 
 static int file_discard(Stream_t *Stream)
 {
+#ifdef BLKFLSBUF
 	int ret;
 	DeclareThis(SimpleFile_t);
-#ifdef BLKFLSBUF
 	ret= ioctl(This->fd, BLKFLSBUF);
 	if(ret < 0)
 		perror("BLKFLSBUF");
 	return ret;
+#else
+	return 0;
 #endif
 }
 
@@ -302,8 +304,6 @@ static int file_discard(Stream_t *Stream)
    group called, say, "ziprw" which has rw permission on /dev/rsd5c, is fine.
  */
 
-#define MAXBLKSPERCMD 255
-
 static void scsi_init(SimpleFile_t *This)
 {
    int fd = This->fd;
@@ -386,7 +386,7 @@ static int scsi_io(Stream_t *Stream, char *buf,
 	if (firstblock > 0x1fffff || nsect > 0xff) {
 		/* I suspect that the ZIP drive also understands Group 1
 		 * commands. If that is indeed true, we may chose Group 1
-		 * more agressively in the future */
+		 * more aggressively in the future */
 
 		cdb[0] |= SCSI_GROUP1;
 		clen=10; /* SCSI Group 1 cmd */
@@ -668,7 +668,7 @@ APIRET rc;
 		} else {
 			*maxSize = max_off_t_seek;
 		}
-		if(This->offset > *maxSize) {
+		if(This->offset > (mt_off_t) *maxSize) {
 			close(This->fd);
 			Free(This);
 			if(errmsg)
